@@ -4,7 +4,9 @@ from .filter import (
     filter_agents_by_labels,
     filter_tl_faces_by_frames,
     filter_tl_faces_by_status,
-    get_agent_by_track_id,
+    get_agents_slice_from_frames,
+    get_frames_slice_from_scenes,
+    get_tl_faces_slice_from_frames,
 )
 from .labels import PERCEPTION_LABEL_TO_INDEX, PERCEPTION_LABELS, TL_FACE_LABEL_TO_INDEX, TL_FACE_LABELS
 from .local_data_manager import DataManager, LocalDataManager
@@ -24,7 +26,6 @@ __all__ = [
     "PERCEPTION_LABELS",
     "PERCEPTION_LABEL_TO_INDEX",
     "filter_agents_by_labels",
-    "get_agent_by_track_id",
     "filter_agents_by_frames",
     "filter_tl_faces_by_frames",
     "MapAPI",
@@ -32,4 +33,7 @@ __all__ = [
     "TL_FACE_LABEL_TO_INDEX",
     "TL_FACE_LABELS",
     "filter_tl_faces_by_status",
+    "get_frames_slice_from_scenes",
+    "get_tl_faces_slice_from_frames",
+    "get_agents_slice_from_frames",
 ]
